
# Class: molecular entity to entity association mixin


An interaction between a molecular entity and another entity

URI: [biolink:MolecularEntityToEntityAssociationMixin](https://w3id.org/biolink/vocab/MolecularEntityToEntityAssociationMixin)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[MolecularEntity]<subject%201..1-%20[MolecularEntityToEntityAssociationMixin],[MolecularEntityToEntityAssociationMixin]^-[DrugToEntityAssociationMixin],[MolecularEntityToEntityAssociationMixin]^-[ChemicalToEntityAssociationMixin],[MolecularEntity],[DrugToEntityAssociationMixin],[ChemicalToEntityAssociationMixin])](https://yuml.me/diagram/nofunky;dir:TB/class/[MolecularEntity]<subject%201..1-%20[MolecularEntityToEntityAssociationMixin],[MolecularEntityToEntityAssociationMixin]^-[DrugToEntityAssociationMixin],[MolecularEntityToEntityAssociationMixin]^-[ChemicalToEntityAssociationMixin],[MolecularEntity],[DrugToEntityAssociationMixin],[ChemicalToEntityAssociationMixin])

## Children

 * [ChemicalToEntityAssociationMixin](ChemicalToEntityAssociationMixin.md) - An interaction between a chemical entity and another entity
 * [DrugToEntityAssociationMixin](DrugToEntityAssociationMixin.md) - An interaction between a drug and another entity

## Referenced by Class


## Attributes


### Own

 * [molecular entity to entity association mixin➞subject](molecular_entity_to_entity_association_mixin_subject.md)  <sub>1..1</sub>
     * Description: the molecular entity that is an interactor
     * Range: [MolecularEntity](MolecularEntity.md)
